@@ -1,6 +1,6 @@
 // image-png.h -- PNG format image handling
 //
-//  Copyright (C) 2005, 2006, 2007, 2011  Miles Bader <miles@gnu.org>
+//  Copyright (C) 2005-2007, 2011, 2012  Miles Bader <miles@gnu.org>
 //
 // This source code is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -15,7 +15,7 @@
 
 #include <cstdio>
 
-#include <libpng/png.h>
+#include <png.h>
 
 #include "image-byte-vec.h"
 
