@@ -10,6 +10,8 @@
 // Written by Miles Bader <miles@gnu.org>
 //
 
+#include <ostream>
+
 #include "nice-io.h"
 
 #include "pos-io.h"
@@ -17,12 +19,12 @@
 std::ostream&
 snogray::operator<< (std::ostream &os, const Pos &pos)
 {
-  os << "pos<";
+  os << "pos{";
   output_nicely (os, pos.x);
   os << ", ";
   output_nicely (os, pos.y);
   os << ", ";
   output_nicely (os, pos.z);
-  os << ">";
+  os << "}";
   return os;
 }
