@@ -1,6 +1,6 @@
 // render-packet.h -- Container for pixels to be rendered and the results
 //
-//  Copyright (C) 2010  Miles Bader <miles@gnu.org>
+//  Copyright (C) 2010, 2011  Miles Bader <miles@gnu.org>
 //
 // This source code is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -10,8 +10,8 @@
 // Written by Miles Bader <miles@gnu.org>
 //
 
-#ifndef __RENDER_PACKET_H__
-#define __RENDER_PACKET_H__
+#ifndef SNOGRAY_RENDER_PACKET_H
+#define SNOGRAY_RENDER_PACKET_H
 
 #include "tint.h"
 
@@ -51,4 +51,4 @@ public:
 
 }
 
-#endif // __RENDER_PACKET_H__
+#endif // SNOGRAY_RENDER_PACKET_H
