@@ -1,6 +1,6 @@
 // rescale-tex.h -- Value rescaling texture
 //
-//  Copyright (C) 2008  Miles Bader <miles@gnu.org>
+//  Copyright (C) 2008, 2011  Miles Bader <miles@gnu.org>
 //
 // This source code is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -10,8 +10,8 @@
 // Written by Miles Bader <miles@gnu.org>
 //
 
-#ifndef __RESCALE_TEX_H__
-#define __RESCALE_TEX_H__
+#ifndef SNOGRAY_RESCALE_TEX_H
+#define SNOGRAY_RESCALE_TEX_H
 
 #include "snogmath.h"
 
@@ -46,4 +46,4 @@ public:
 
 }
 
-#endif // __RESCALE_TEX_H__
+#endif // SNOGRAY_RESCALE_TEX_H
