@@ -1,6 +1,6 @@
 // zero-surface-integ.h -- Constant-zero SurfaceInteg
 //
-//  Copyright (C) 2010  Miles Bader <miles@gnu.org>
+//  Copyright (C) 2010, 2011  Miles Bader <miles@gnu.org>
 //
 // This source code is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -10,8 +10,8 @@
 // Written by Miles Bader <miles@gnu.org>
 //
 
-#ifndef __ZERO_SURFACE_INTEG_H__
-#define __ZERO_SURFACE_INTEG_H__
+#ifndef SNOGRAY_ZERO_SURFACE_INTEG_H
+#define SNOGRAY_ZERO_SURFACE_INTEG_H
 
 #include "surface-integ.h"
 
@@ -69,4 +69,4 @@ protected:
 
 }
 
-#endif // __ZERO_SURFACE_INTEG_H__
+#endif // SNOGRAY_ZERO_SURFACE_INTEG_H
